@@ -173,7 +173,10 @@ if detected.cygwin then
    defaults.variables.LIBFLAG = "-shared"
 end
 
+defaults.external_lib_extension = defaults.lib_extension
+
 if detected.macosx then
+   defaults.external_lib_extension = "dylib"
    defaults.arch = "macosx-"..proc
    defaults.platforms = {"unix", "macosx"}
    defaults.variables.CC = "export MACOSX_DEPLOYMENT_TARGET=10.3; gcc"
