@@ -1,5 +1,5 @@
 
-program_version = "1.0"
+program_version = "1.0.1"
 
 --- Functions for command-line scripts.
 module("luarocks.command_line", package.seeall)
@@ -78,7 +78,8 @@ function run_command(...)
       if flags["from"] == true then
          die("Argument error: use --from=<url>")
       end
-      table.insert(cfg.rocks_servers, 1, flags["from"])
+      local protocol, path = fs.split_url(flags["from"])
+      table.insert(cfg.rocks_servers, 1, protocol.."://"..path)
    end
    
    if flags["only-from"] then
