@@ -535,6 +535,9 @@ function check_external_deps(rockspec, mode)
                   local found = false
                   failed_file = nil
                   for _, f in pairs(files) do
+                     if f:match("%.so$") or f:match("%.dylib$") or f:match("%.dll$") then
+                        f = f:gsub("%.[^.]+$", "."..cfg.external_lib_extension)
+                     end
                      local testfile = fs.make_path(dirdata.dir, f)
                      if fs.exists(testfile) then
                         found = true
