@@ -128,12 +128,19 @@ function load_local_rockspec(filename)
    local ok, err = type_check.type_check_rockspec(rockspec)
    if not ok then
       return nil, filename..": "..err
-   end   
+   end
+   
+   if rockspec.rockspec_format then
+      if deps.compare_versions(rockspec.rockspec_format, type_check.rockspec_format) then
+         return nil, "Rockspec format "..rockspec.rockspec_format.." is not supported, please upgrade LuaRocks."
+      end
+   end
 
    util.platform_overrides(rockspec.build)
    util.platform_overrides(rockspec.dependencies)
    util.platform_overrides(rockspec.external_dependencies)
    util.platform_overrides(rockspec.source)
+   util.platform_overrides(rockspec.hooks)
 
    local basename = fs.base_name(filename)
    rockspec.name = basename:match("(.*)-[^-]*-[0-9]*")
