@@ -11,10 +11,13 @@ module("luarocks.fs", package.seeall)
 local cfg = require("luarocks.cfg")
 
 local fs_impl = nil
-for _, platform in pairs(cfg.platforms) do
-   fs_impl = require("luarocks.fs."..platform)
-   if fs_impl then
-      break
+for _, platform in ipairs(cfg.platforms) do
+   local ok, result = pcall(require, "luarocks.fs."..platform)
+   if ok then
+      fs_impl = result
+      if fs_impl then
+         break
+      end
    end
 end
 
@@ -22,7 +25,7 @@ local fs_unix = require("luarocks.fs.unix")
 
 local fs_mt = {
    __index = function(t, k)
-      local impl = fs_impl[k]
+      local impl = fs_impl and fs_impl[k]
       if not impl then
          impl = fs_unix[k]
       end
@@ -34,4 +37,7 @@ local fs_mt = {
 setmetatable(luarocks.fs, fs_mt)
 
 fs_unix.init_fs_functions(luarocks.fs)
-fs_impl.init_fs_functions(luarocks.fs)
+if fs_impl then
+   fs_impl.init_fs_functions(luarocks.fs)
+end
+
