@@ -140,15 +140,6 @@ function remove_dir_if_empty(dir)
    fs_execute_string("rmdir "..fs_Q(dir).." 1> /dev/null 2> /dev/null")
 end
 
---- Move a file from one location to another
--- @param src string: Pathname of source
--- @param dest string: Pathname of destination
--- @return boolean: true on success, false on failure.
-function move(src, dest)
-   assert(src and dest)
-   return fs_execute("mv", src, dest)
-end
-
 --- Copy a file.
 -- @param src string: Pathname of source
 -- @param dest string: Pathname of destination
@@ -170,7 +161,7 @@ end
 -- plus an error message.
 function copy_contents(src, dest)
    assert(src and dest)
-   if fs_execute_string("cp -a "..fs_Q(src).."/* "..fs_Q(dest).." 1> /dev/null 2>/dev/null") then
+   if fs_execute_string("cp -pPR "..fs_Q(src).."/* "..fs_Q(dest).." 1> /dev/null 2>/dev/null") then
       return true
    else
       return false, "Failed copying "..src.." to "..dest
@@ -197,10 +188,10 @@ function dir(at)
    if not at then
       at = fs_current_dir()
    end
-   local result = {}
    if not fs_is_dir(at) then
       return {}
    end
+   local result = {}
    local pipe = io.popen("cd "..fs_Q(at).." && ls")
    for file in pipe:lines() do
       table.insert(result, file)
@@ -219,10 +210,10 @@ function find(at)
    if not at then
       at = fs_current_dir()
    end
-   local result = {}
    if not fs_is_dir(at) then
       return {}
    end
+   local result = {}
    local pipe = io.popen("cd "..fs_Q(at).." && find * 2>/dev/null") 
    for file in pipe:lines() do
       table.insert(result, file)
@@ -253,7 +244,7 @@ end
 -- @return boolean: true if file exists, false otherwise.
 function exists(file)
    assert(file)
-   return fs_execute("test -e", file)
+   return fs_execute("test -r", file)
 end
 
 --- Test is file/dir is writable.
@@ -335,7 +326,7 @@ end
 --- Apply a patch.
 -- @param patchname string: The filename of the patch.
 function patch(patchname)
-   return fs_execute("patch -p1 -i ", patchname)
+   return fs_execute("patch -p1 -f -i ", patchname)
 end
 
 --- Unpack an archive.
@@ -390,6 +381,13 @@ function check_md5(file, md5sum)
       if computed then
          computed = computed:sub(-32)
       end
+   elseif cfg.md5checker == "md5" then
+      local pipe = io.popen("md5 "..file)
+      computed = pipe:read("*l")
+      pipe:close()
+      if computed then
+         computed = computed:sub(-32)
+      end
    end
    if not computed then
       return false
