@@ -6,6 +6,7 @@ module("luarocks.list", package.seeall)
 local search = require("luarocks.search")
 local cfg = require("luarocks.cfg")
 local util = require("luarocks.util")
+local fs = require("luarocks.fs")
 
 help_summary = "Lists currently installed rocks."
 
@@ -22,7 +23,9 @@ function run(...)
    local results = {}
    local query = search.make_query(filter or "", version)
    query.exact_name = false
-   search.manifest_search(results, cfg.rocks_dir, query)
+   for _, tree in ipairs(cfg.rocks_trees) do
+      search.manifest_search(results, fs.make_path(tree, "rocks"), query)
+   end
    print()
    print("Installed rocks:")
    print("----------------")
