@@ -23,5 +23,10 @@ function run(repo)
   
    print("Making manifest for "..repo)
    
-   return manif.make_manifest(repo)
+   ok = manif.make_manifest(repo)
+   if ok then
+      print("Generating index.html for "..repo)
+      manif.make_index(repo)
+   end
+   return ok
 end
