@@ -346,6 +346,9 @@ td.version {
    padding: 5px;
    width: 100px;
 }
+p.manifest {
+   font-size: 8px;
+}
 </style>
 </head>
 <body>
@@ -372,6 +375,9 @@ local index_package_end = [[
 
 local index_footer = [[
 </table>
+<p class="manifest">
+<a href="manifest">manifest file</a>
+</p>
 </body>
 </html>
 ]]
