@@ -63,7 +63,7 @@ local function write_table(out, tbl)
       elseif typ == "string" then
          out:write("'"..v:gsub("'", "\\'").."'")
       else
-         out:write(v)
+         out:write(tostring(v))
       end
       sep = ", "
    end
