@@ -38,6 +38,8 @@ rockspec_types = {
       md5 = "string",
       file = "string",
       dir = "string",
+      tag = "string",
+      branch = "string",
       cvs_tag = "string",
       cvs_module = "string"
    },
